==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Edit/Paste/ts/Paste_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>Paste</name>
    <message>
        <location filename="../Paste.ui" line="+17"/>
        <source>Rotation:</source>
        <translation>Rotazione:</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Rotate pasted entities&lt;br&gt;by this angle</source>
        <translation>Ruotare le entità incollato&lt;br&gt;da questa angolazione</translation>
    </message>
    <message>
        <location line="+97"/>
        <source>Scale:</source>
        <translation>Scala:</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Scale pasted entities&lt;br&gt;by this factor</source>
        <translation>Scala entità incollate&lt;br&gt;da questo fattore</translation>
    </message>
    <message>
        <location line="+72"/>
        <source>Flip pasted entities&lt;br&gt;horizontally</source>
        <translation>Rifletti entità&lt;br&gt;incollate orizzontalmente</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Flip pasted entities&lt;br&gt;vertically</source>
        <translation>Rifletti entità&lt;br&gt;incollate verticalmente</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Paste all entities&lt;br&gt;to current layer&lt;br&gt;instead of original layer</source>
        <translation>Incolla tutte le entità&lt;br&gt;al layer corrente al&lt;br&gt;posto del layer originale</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>To current layer</source>
        <translation>Al layer attuale</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Overwrite existing layers&lt;br&gt;in drawing with&lt;br&gt;layers from clipboard</source>
        <translation>Sovrascrivere eventuali layer&lt;br&gt;esistenti nel disegno&lt;br&gt;con gli layer di appunti</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Overwrite layers</source>
        <translation>Sovrascrivere layer</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Overwrite existing blocks&lt;br&gt;in drawing with&lt;br&gt;blocks from clipboard</source>
        <translation>Sovrascrivere i blocchi&lt;br&gt;esistenti in blocchi&lt;br&gt;da disegno con appunti</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Overwrite blocks</source>
        <translation>Sovrascrivere i blocchi</translation>
    </message>
    <message>
        <location filename="../Paste.js" line="+77"/>
        <source>Position</source>
        <translation>Posizione</translation>
    </message>
    <message>
        <location filename="../PasteInit.js" line="+2"/>
        <source>&amp;Paste</source>
        <translation>&amp;Incolla</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Edit/Paste/ts/Paste_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>Paste</name>
    <message>
        <location filename="../Paste.ui" line="+17"/>
        <source>Rotation:</source>
        <translation>Rotazione:</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Rotate pasted entities&lt;br&gt;by this angle</source>
        <translation>Ruotare le entità incollato&lt;br&gt;da questa angolazione</translation>
    </message>
    <message>
        <location line="+107"/>
        <source>Scale:</source>
        <translation>Scala:</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Scale pasted entities&lt;br&gt;by this factor</source>
        <translation>Scala entità incollate&lt;br&gt;da questo fattore</translation>
    </message>
    <message>
        <location line="+72"/>
        <source>Flip pasted entities&lt;br&gt;horizontally</source>
        <translation>Rifletti entità&lt;br&gt;incollate orizzontalmente</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Flip pasted entities&lt;br&gt;vertically</source>
        <translation>Rifletti entità&lt;br&gt;incollate verticalmente</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Paste all entities&lt;br&gt;to current layer&lt;br&gt;instead of original layer</source>
        <translation>Incolla tutte le entità&lt;br&gt;al layer corrente al&lt;br&gt;posto del layer originale</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>To current layer</source>
        <translation>Al layer attuale</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Overwrite existing layers&lt;br&gt;in drawing with&lt;br&gt;layers from clipboard</source>
        <translation>Sovrascrivere eventuali layer&lt;br&gt;esistenti nel disegno&lt;br&gt;con gli layer di appunti</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Overwrite layers</source>
        <translation>Sovrascrivere layer</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Overwrite existing blocks&lt;br&gt;in drawing with&lt;br&gt;blocks from clipboard</source>
        <translation>Sovrascrivere i blocchi&lt;br&gt;esistenti in blocchi&lt;br&gt;da disegno con appunti</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Overwrite blocks</source>
        <translation>Sovrascrivere i blocchi</translation>
    </message>
    <message>
        <location filename="../Paste.js" line="+52"/>
        <source>Edit</source>
        <translation>Modifica</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Paste</source>
        <translation>Incolla</translation>
    </message>
    <message>
        <location line="+40"/>
        <source>Position</source>
        <translation>Posizione</translation>
    </message>
    <message>
        <location filename="../PasteInit.js" line="+2"/>
        <source>&amp;Paste</source>
        <translation>&amp;Incolla</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Reset to defaults every time tool is used</source>
        <translation>Ripristina impostazioni predefinite viene utilizzato ogni strumento tempo</translation>
    </message>
</context>
</TS>
